@@ -204,7 +204,7 @@ class User(AbstractBaseUser, PermissionsMixin):
             im.save(user_photo.file.path, format='JPEG')
         except IOError:
             user_photo.destroy() # In order to not get stuck with an invalid image and, therefore, a nasty icon in the browser :P
-            logger.error('Error resizing user photo! User: ' + str(self.email))
+            logger.error('Error resizing user photo! User: ' + str(self.email), exc_info=1)
             raise
         
         # 5) Return.
